%define build_nox 1

Name:		qbittorrent
Version:	4.3.3
Release:	%mkrel 1
Summary:	A lightweight but featureful BitTorrent client
Group:		Networking/File transfer
License:	GPLv2+
Url:		https://qbittorrent.sourceforge.net/
Source0:	https://downloads.sourceforge.net/qbittorrent/qbittorrent-%{version}.tar.xz
# From FC:
# These flags are needed for the hardening feature. It's probably not interesting for upstream
Patch1:		qbittorrent-4.1.1-build_flags.patch
# disable silent qmake config, enable verbose build
Patch3:		qbittorrent-3.3.1-verbose_build.patch
BuildRequires:	cmake
BuildRequires:	ninja-build
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Concurrent)
BuildRequires:	pkgconfig(Qt5DBus)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Help)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5Svg)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(Qt5Xml)
BuildRequires:	boost-devel
BuildRequires:	pkgconfig(libtorrent-rasterbar) >= 1.1.4
BuildRequires:	systemd
Requires:	python3

%description
A lightweight but feature-full BitTorrent client that aims to be very easy
to use. It is multi-platform and provides a Qt5 graphical interface.

%package -n %{name}-nox
Summary:	A Headless Bittorrent Client
Group:		Networking/File transfer
BuildRequires:	qtsinglecoreapplication-qt5-devel

%description -n %{name}-nox
A Headless Bittorrent Client with a feature rich Web UI allowing users to
control the clinet remotely.

%prep
%setup -q
%autopatch -p1

cp -a . %{_builddir}/build-nox

%build
export LDFLAGS="%{?__global_ldflags} -pthread"

### Build headless first
%if %build_nox
pushd %{_builddir}/build-nox
%cmake -GNinja -DVERBOSE_CONFIGURE=ON -DSYSTEMD=ON -DGUI=OFF
%cmake_build
popd
%endif

### Build gui version
%cmake -GNinja -DVERBOSE_CONFIGURE=ON
%cmake_build

%install
### install headless version
%if %build_nox
pushd %{_builddir}/build-nox
%cmake_install
popd
%endif

### install gui version
%cmake_install

%files
%license COPYING
%doc AUTHORS Changelog README.md TODO
%{_bindir}/%{name}
%{_datadir}/applications/org.%{name}.qBittorrent.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_iconsdir}/hicolor/*/status/%{name}-tray.png
%{_iconsdir}/hicolor/*/status/%{name}-tray*.svg
%{_mandir}/man1/%{name}.1*
%{_metainfodir}/org.%{name}.qBittorrent.appdata.xml

%if %build_nox
%files -n  %{name}-nox
%{_bindir}/%{name}-nox
%{_mandir}/man1/%{name}-nox.1*
%{_unitdir}/qbittorrent-nox@.service
%endif


%changelog
* Mon Mar 01 2021 daviddavid <daviddavid> 4.3.3-1.mga8
+ Revision: 1694914
- new version: 4.3.3, fixes crash (mga#28484)
- switch to cmake build system

* Mon Dec 28 2020 daviddavid <daviddavid> 4.3.2-1.mga8
+ Revision: 1664360
- new version: 4.3.2

* Thu Dec 17 2020 umeabot <umeabot> 4.3.1-2.mga8
+ Revision: 1659444
- Rebuild for new Qt5

* Wed Nov 25 2020 kekepower <kekepower> 4.3.1-1.mga8
+ Revision: 1649312
- Update to version 4.3.1

* Thu Oct 22 2020 kekepower <kekepower> 4.3.0.1-1.mga8
+ Revision: 1638368
- Update to version 4.3.0.1
+ tv <tv>
- rebuild for new libtorrent-rasterbar

* Mon Oct 19 2020 tv <tv> 4.3.0-2.mga8
+ Revision: 1637064
- rebuild for new libtorrent-rasterbar

* Mon Oct 19 2020 kekepower <kekepower> 4.3.0-1.mga8
+ Revision: 1636874
- Update to version 4.3.0

* Mon Aug 31 2020 tv <tv> 4.2.5-2.mga8
+ Revision: 1620240
- rebuild due to symbol lookup error

* Sat Apr 25 2020 kekepower <kekepower> 4.2.5-1.mga8
+ Revision: 1571855
- Update to version 4.2.5

* Thu Apr 23 2020 kekepower <kekepower> 4.2.4-1.mga8
+ Revision: 1571195
- Update to version 4.2.4

* Thu Apr 02 2020 kekepower <kekepower> 4.2.3-1.mga8
+ Revision: 1564091
- Update to version 4.2.3

* Tue Mar 24 2020 kekepower <kekepower> 4.2.2-1.mga8
+ Revision: 1559533
- Update to version 4.2.2

* Fri Feb 21 2020 umeabot <umeabot> 4.2.1-4.mga8
+ Revision: 1547785
- Mageia 8 Mass Rebuild
+ daviddavid <daviddavid>
- qtsingleapplication is no more needed

* Mon Feb 10 2020 daviddavid <daviddavid> 4.2.1-3.mga8
+ Revision: 1488341
- rebuild for new libtorrent-rasterbar 1.2.4

* Sun Jan 26 2020 wally <wally> 4.2.1-2.mga8
+ Revision: 1483426
- rebuild for boost 1.72.0
- replace deprecated %%configure2_5x
- replace deprecated %%setup_compile_flags

* Wed Dec 18 2019 kekepower <kekepower> 4.2.1-1.mga8
+ Revision: 1468681
- Update to version 4.2.1

* Sun Dec 08 2019 kekepower <kekepower> 4.2.0-1.mga8
+ Revision: 1465234
- Update to version 4.2.0

* Fri Nov 01 2019 kekepower <kekepower> 4.1.9.1-1.mga8
+ Revision: 1457237
- Update to version 4.1.9.1

* Mon Oct 28 2019 kekepower <kekepower> 4.1.9-1.mga8
+ Revision: 1456270
- Update to version 4.1.9

* Mon Sep 30 2019 kekepower <kekepower> 4.1.8-1.mga8
+ Revision: 1448340
- Update to version 4.1.8

* Mon Aug 05 2019 kekepower <kekepower> 4.1.7-1.mga8
+ Revision: 1427362
- Update to version 4.1.7

* Mon May 06 2019 kekepower <kekepower> 4.1.6-1.mga7
+ Revision: 1396482
- Update to version 4.1.6

* Mon Apr 01 2019 umeabot <umeabot> 4.1.5-2.mga7
+ Revision: 1384130
- Qt5 Rebuild

* Wed Dec 26 2018 kekepower <kekepower> 4.1.5-1.mga7
+ Revision: 1345032
- Update to version 4.1.5
- Rediffed Patch3
- Removed merged Patch4

* Mon Nov 19 2018 kekepower <kekepower> 4.1.4-2.mga7
+ Revision: 1331705
- Rediffed Patch4 to enable compiling with C++14

* Mon Nov 19 2018 kekepower <kekepower> 4.1.4-1.mga7
+ Revision: 1331642
- Update to version 4.1.4
- Remove merged upstream patch (Patch4)

* Fri Oct 19 2018 tv <tv> 4.1.3-5.mga7
+ Revision: 1322404
- disable debug mode, use release mode
- got debuginfo the same way as FC
- one configure option per line
- explicitely enable verbose build output
- use %%license

* Fri Oct 19 2018 tv <tv> 4.1.3-4.mga7
+ Revision: 1322375
- stop unpacking twice the sources, thus fixing the nox build segfaulting due
  to not being patched

* Thu Oct 18 2018 daviddavid <daviddavid> 4.1.3-3.mga7
+ Revision: 1322204
- compile with the C++14 ABI for now to fix a segfault, as otherwise
  qbittorrent gets built with the C++11 one for odd reasons, which
  is not what boost and libtorrent-rasterbar are built with
  https://github.com/qbittorrent/qBittorrent/issues/9485

* Tue Oct 16 2018 wally <wally> 4.1.3-2.mga7
+ Revision: 1321090
- rebuild for new boost 1.68.0

* Mon Oct 01 2018 daviddavid <daviddavid> 4.1.3-1.mga7
+ Revision: 1314254
- new version: 4.1.3
- remove merged upstream patch

* Sun Sep 23 2018 umeabot <umeabot> 4.1.2-2.mga7
+ Revision: 1300634
- Mageia 7 Mass Rebuild

* Wed Aug 15 2018 daviddavid <daviddavid> 4.1.2-1.mga7
+ Revision: 1251676
- new version: 4.1.2

* Mon May 28 2018 daviddavid <daviddavid> 4.1.1-1.mga7
+ Revision: 1232742
- new version: 4.1.1
- rename and rediff build_flags patch

* Sat May 05 2018 daviddavid <daviddavid> 4.1.0-1.mga7
+ Revision: 1226378
- new version: 4.1.0

* Thu Feb 22 2018 daviddavid <daviddavid> 4.0.4-1.mga7
+ Revision: 1204217
- new version: 4.0.4

* Thu Jan 04 2018 daviddavid <daviddavid> 4.0.3-1.mga7
+ Revision: 1190220
- new version: 4.0.3

* Mon Dec 25 2017 wally <wally> 4.0.1-3.mga7
+ Revision: 1184704
- rebuild for new boost

* Fri Nov 24 2017 tv <tv> 4.0.1-2.mga7
+ Revision: 1179122
- bump release
- fix finding boost
+ daviddavid <daviddavid>
- new version: 4.0.1

* Sun Nov 19 2017 tv <tv> 3.3.16-2.mga7
+ Revision: 1177746
- rebuild for boost 1.65

* Thu Sep 28 2017 tv <tv> 3.3.16-1.mga7
+ Revision: 1160980
- new release

* Wed Sep 13 2017 tv <tv> 3.3.14-1.3.mga7
+ Revision: 1153553
- rebuild for new libtorrent + boost
- use python3 for runtime (rhbz#1471349)
- scrap the remove donate patch out

* Tue Jul 25 2017 daviddavid <daviddavid> 3.3.14-1.mga7
+ Revision: 1130822
- new version: 3.3.14
+ tv <tv>
- do not package useless NEWS file

* Fri May 26 2017 eatdirt <eatdirt> 3.3.12-1.mga6
+ Revision: 1104813
- Upgrade to version 3.3.12

* Sun Mar 05 2017 daviddavid <daviddavid> 3.3.11-1.mga6
+ Revision: 1088800
- new version: 3.3.11

* Wed Jan 04 2017 daviddavid <daviddavid> 3.3.10-1.mga6
+ Revision: 1080036
- new version: 3.3.10

* Thu Sep 15 2016 daviddavid <daviddavid> 3.3.7-1.mga6
+ Revision: 1053187
- new version: 3.3.7

* Fri Aug 12 2016 daviddavid <daviddavid> 3.3.6-1.mga6
+ Revision: 1046037
- new version: 3.3.6
- use %%configure2_5x macro

* Thu Jun 30 2016 daviddavid <daviddavid> 3.3.5-1.mga6
+ Revision: 1038219
- new version: 3.3.5
- rename and rediff remove_donate patch

* Tue Apr 12 2016 daviddavid <daviddavid> 3.3.4-1.mga6
+ Revision: 1000778
- new version: 3.3.4
- rename and rediff remove_donate patch

* Thu Jan 21 2016 daviddavid <daviddavid> 3.3.3-1.mga6
+ Revision: 926225
- new version: 3.3.3

* Wed Jan 20 2016 daviddavid <daviddavid> 3.3.2-1.mga6
+ Revision: 926059
- new version: 3.3.2

* Fri Jan 08 2016 daviddavid <daviddavid> 3.3.1-1.mga6
+ Revision: 920589
- new version: 3.3.1
- switch build to Qt5
- switch BR to qtsingleapplication-qt5-devel
- rename and rediff remove_donate patch

* Sun Dec 27 2015 tv <tv> 3.2.3-3.mga6
+ Revision: 915893
- rebuild for new boost

* Fri Sep 25 2015 tv <tv> 3.2.3-2.mga6
+ Revision: 883533
- rebuild for new boost

* Sun Sep 20 2015 matteo <matteo> 3.2.3-1.mga6
+ Revision: 881658
- enable debug
- new version 3.2.3

* Thu Aug 27 2015 cjw <cjw> 3.2.1-4.mga6
+ Revision: 870192
- rebuild with gcc 5

* Sun Aug 02 2015 daviddavid <daviddavid> 3.2.1-3.mga6
+ Revision: 860616
- rebuild for new boost-1.58.0

* Sun Jul 26 2015 tv <tv> 3.2.1-2.mga6
+ Revision: 857931
- patch 1: remove "donate" entry (from FC, rediffed)
- include systemd file for nox

* Sat Jul 25 2015 tv <tv> 3.2.1-1.mga6
+ Revision: 857235
- adjust file list
- remove qtdir option from 2nd configure call too
- drop support for mga1...
- new release
- rebuild for new libtorrent-rasterbar
+ daviddavid <daviddavid>
- rebuild for new libtorrent-rasterbar-1.0.5

* Fri Nov 21 2014 matteo <matteo> 3.1.11-1.mga5
+ Revision: 798083
- new minor release 3.1.11

* Wed Oct 15 2014 umeabot <umeabot> 3.1.9.2-2.mga5
+ Revision: 742801
- Second Mageia 5 Mass Rebuild

* Fri Jun 27 2014 matteo <matteo> 3.1.9.2-1.mga5
+ Revision: 640458
- new version 3.1.9.2

* Sun Jun 08 2014 matteo <matteo> 3.1.9-2.mga5
+ Revision: 634819
- rebuilt against new libtorrent-rasterbar-0.16.16

* Thu Mar 06 2014 matteo <matteo> 3.1.9-1.mga5
+ Revision: 600540
- new version 3.1.9

* Sat Feb 08 2014 barjac <barjac> 3.1.0-3.mga5
+ Revision: 586845
- rebuild against boost-1.55

* Tue Oct 22 2013 umeabot <umeabot> 3.1.0-2.mga4
+ Revision: 545324
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 matteo <matteo> 3.1.0-1.mga4
+ Revision: 501111
- new version 3.1.0

* Mon Sep 23 2013 fwang <fwang> 3.0.11-1.mga4
+ Revision: 483718
- new version 3.0.11

* Sun Aug 18 2013 matteo <matteo> 3.0.10-2.mga4
+ Revision: 467447
- rebuilt against new libtorrent-rasterbar

* Sat Jul 27 2013 matteo <matteo> 3.0.10-1.mga4
+ Revision: 459019
- new version

* Wed Jul 10 2013 fwang <fwang> 3.0.9-3.mga4
+ Revision: 452497
- rebuild for new boost

* Thu Apr 11 2013 barjac <barjac> 3.0.9-2.mga3
+ Revision: 409678
- rebuild for boost-1.53

* Sat Mar 23 2013 matteo <matteo> 3.0.9-1.mga3
+ Revision: 404709
- new version

* Tue Jan 22 2013 matteo <matteo> 3.0.8-1.mga3
+ Revision: 391124
- new version

* Fri Jan 18 2013 fwang <fwang> 3.0.6-3.mga3
+ Revision: 389276
- rebuild for new libtorrent

* Thu Dec 20 2012 fwang <fwang> 3.0.6-2.mga3
+ Revision: 333091
- rebuild for new boost

* Wed Oct 17 2012 matteo <matteo> 3.0.6-1.mga3
+ Revision: 307427
- new version

* Sat Oct 06 2012 matteo <matteo> 3.0.5-1.mga3
+ Revision: 302979
- new version

* Sat Sep 15 2012 fwang <fwang> 3.0.2-1.mga3
+ Revision: 294130
- new version 3.0.2

* Sun Aug 12 2012 doktor5000 <doktor5000> 3.0.0-1.mga3
+ Revision: 280925
- new version 3.0.0 (new stable branch)

* Sun Aug 05 2012 doktor5000 <doktor5000> 2.9.10-1.mga3
+ Revision: 278803
- new version 2.9.10 (2.9.11 seems too crashy)
- removed obsolete clean section and empty defattrs

* Tue Jul 31 2012 fwang <fwang> 2.9.3-3.mga3
+ Revision: 276588
- rebuild for new boost

* Wed May 30 2012 fwang <fwang> 2.9.3-2.mga3
+ Revision: 250119
- do not set locale based dir

* Tue Jan 24 2012 fwang <fwang> 2.9.3-1.mga2
+ Revision: 200522
- new version 2.9.3

* Mon Nov 28 2011 fwang <fwang> 2.9.2-2.mga2
+ Revision: 173628
- rebuild for new boost

* Mon Oct 31 2011 fwang <fwang> 2.9.2-1.mga2
+ Revision: 160354
- new version 2.9.2
- new version 2.8.4
- rebuild for new boost
+ ahmad <ahmad>
- Update to 2.8.3
- Fix %%mgaversion again

* Wed Jun 22 2011 fwang <fwang> 2.8.2-3.mga2
+ Revision: 111938
- fix building
- rebuild for new boost
+ ahmad <ahmad>
- Build with system qtsingeapplication
- Don't explicitly require geoip, it's already required by libtorrent-rasterbar
- Don't disable the geoip database for nox

* Sat Jun 18 2011 ahmad <ahmad> 2.8.2-1.mga2
+ Revision: 109492
- Update to 2.8.2

* Tue Jun 07 2011 ahmad <ahmad> 2.8.1-1.mga2
+ Revision: 101611
- Update to 2.8.1
- Update to 2.8.0rc2

* Mon May 02 2011 ahmad <ahmad> 2.8.0-0.beta5.1.mga1
+ Revision: 94292
- Update to 2.8.0beta5

* Mon Apr 18 2011 ahmad <ahmad> 2.8.0-0.beta4.1.mga1
+ Revision: 87567
- Update to 2.8.0beta4

* Sat Apr 16 2011 ahmad <ahmad> 2.8.0-0.beta3.1.mga1
+ Revision: 86801
- update to 2.8.0beta3
- drop libnotify-devel BR completely upstream now uses dbus

* Sun Apr 10 2011 ahmad <ahmad> 2.8.0-0.beta1.1.mga1
+ Revision: 82711
- update to 2.8.0beta1
- drop the deprecated --disable-libnotify from nox configure options

* Sat Mar 26 2011 ahmad <ahmad> 2.7.1-1.mga1
+ Revision: 77740
- update to 2.7.1

* Sun Mar 20 2011 ahmad <ahmad> 2.7.0-1.mga1
+ Revision: 74968
- update to 2.7.0

* Sun Mar 13 2011 ahmad <ahmad> 2.7.0-0.beta4.1.mga1
+ Revision: 70822
- update to 2.7.0beta4

* Sun Mar 13 2011 ahmad <ahmad> 2.7.0-0.beta3.1.mga1
+ Revision: 70731
- update to 2.7.0beta3

* Sun Feb 27 2011 ahmad <ahmad> 2.7.0-0.beta2.1.mga1
+ Revision: 61193
- update to 2.7.0beta2

* Fri Feb 25 2011 ahmad <ahmad> 2.7.0-0.beta1.1.mga1
+ Revision: 59973
- update to 2.7.0beta1
- simplify building the nox and the gui, similar trick to the one used to build
  wxgtk, and wxgtku in the wxgtk2.8 spec

* Tue Feb 08 2011 ahmad <ahmad> 2.6.6-1.mga1
+ Revision: 49208
- update to 2.6.6
- update to 2.6.5

* Mon Jan 24 2011 ahmad <ahmad> 2.6.4-1.mga1
+ Revision: 36008
- update to 2.6.4

* Sun Jan 16 2011 ahmad <ahmad> 2.6.3-1.mga1
+ Revision: 19970
- update to 2.6.3
- imported package qbittorrent


* Thu Jan 06 2011 Ahmad Samir <ahmadsamir@mandriva.org> 2.6.0-0.rc2.1mdv2011.0
+ Revision: 629152
- update to 2.6.0rc2
- drop unused patch

* Sat Jan 01 2011 Ahmad Samir <ahmadsamir@mandriva.org> 2.6.0-0.beta4.1mdv2011.0
+ Revision: 627199
- update to 2.6.0beta3

* Sat Dec 25 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.6.0-0.beta2.1mdv2011.0
+ Revision: 625050
- update to 2.6.0beta2

* Sun Dec 19 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.6.0-0.beta1.1mdv2011.0
+ Revision: 623027
- update to 2.6.0beta1
- improve spec

* Sun Dec 05 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.5.1-1mdv2011.0
+ Revision: 609691
- update to 2.5.1

* Sun Dec 05 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.5.0-1mdv2011.0
+ Revision: 609636
- update to 2.5.0

* Mon Nov 29 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.5.0-0.rc4.2mdv2011.0
+ Revision: 603117
- update to 2.5.0rc4
- drop patch1, fixed upstream

* Fri Nov 26 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.5.0-0.rc2.2mdv2011.0
+ Revision: 601594
- add patch from upstream to fix possible crash when loading columns visual indexes

* Thu Nov 25 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.5.0-0.rc2.1mdv2011.0
+ Revision: 601247
- update to 2.5.0rc2

* Tue Nov 23 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.5.0-0.rc1.1mdv2011.0
+ Revision: 600252
- update to 2.5.0rc1
- bump qt4 BR to 4.5
- fix qt4-devel BR (by adding the Epoch)

* Tue Nov 23 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.5.0-0.beta7.1mdv2011.0
+ Revision: 599882
- update to 2.5.0beta7 and drop patch1 (merged upstream)

* Thu Nov 18 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.5.0-0.beta4.1mdv2011.0
+ Revision: 598797
- Update to 2.5.0beta4
- Add patch from upstream to fix compilation errors

* Sun Nov 14 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.5.0-0.beta3.1mdv2011.0
+ Revision: 597481
- Update to 2.5.0beta3

* Sun Nov 07 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.5.0-0.beta2.1mdv2011.0
+ Revision: 594635
- update to 2.5.0 beta2

* Sun Oct 31 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.4.9-1mdv2011.0
+ Revision: 591214
- update to 2.4.9
- drop merged patch

* Tue Oct 26 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.4.8-2mdv2011.0
+ Revision: 589510
- add upstream patch to fix a crash when pressing Enter in the in the save path
  field of the torrent addition dialogue

* Sun Oct 24 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.4.8-1mdv2011.0
+ Revision: 588287
- update to 2.4.8

* Wed Oct 20 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.4.7-1mdv2011.0
+ Revision: 586908
- update to 2.4.7

* Sun Oct 17 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.4.6-1mdv2011.0
+ Revision: 586378
- update to 2.4.6

* Tue Oct 12 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.4.5-1mdv2011.0
+ Revision: 585197
- update to 2.4.5

* Sat Oct 02 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.4.4-1mdv2011.0
+ Revision: 582427
- update to 2.4.4

* Tue Sep 28 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.4.3-1mdv2011.0
+ Revision: 581850
- update to 2.4.3

* Sun Sep 26 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.4.2-1mdv2011.0
+ Revision: 581119
- update to 2.4.2

* Sun Sep 26 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.4.1-1mdv2011.0
+ Revision: 581051
- update to 2.4.1

* Wed Aug 25 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.4.0-1mdv2011.0
+ Revision: 573328
- update to 2.4.0 final

* Fri Aug 20 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.4.0-0.rc1.1mdv2011.0
+ Revision: 571485
- change spec to make it easier to package pre-releases (thanks to the meticulous
  transmission.spec)
- update to 2.4.0rc1

* Tue Aug 17 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.3.1-1mdv2011.0
+ Revision: 570997
- update to 2.3.1

* Wed Aug 04 2010 Funda Wang <fwang@mandriva.org> 2.3.0-2mdv2011.0
+ Revision: 566031
- rebuild for new boost

* Tue Jul 27 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.3.0-1mdv2011.0
+ Revision: 562091
- update to 2.3.0 final

* Sat Jul 24 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.3.0-0.rc10.1mdv2011.0
+ Revision: 558200
- 2.3.0rc10
- update to 2.3.0rc9

* Wed Jul 21 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.3.0-0.rc7.1mdv2011.0
+ Revision: 556352
- update to 2.3.0rc7

* Mon Jul 19 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.3.0-0.rc5.1mdv2011.0
+ Revision: 555018
- update to 2.3.0rc5
- update to 2.3.0rc4
- update to 2.3.0rc2

* Wed Jun 23 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.10-1mdv2010.1
+ Revision: 548726
- new bug fix release, 2.2.10
- drop patch1, merged upstream

* Thu Jun 17 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.9-2mdv2010.1
+ Revision: 548245
- add patch from upstream to fix web ui

* Sun Jun 13 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.9-1mdv2010.1
+ Revision: 547954
- new upstream bug fix release 2.2.9
- drop patch1, merged upstream
- use the actual source url
- fix typo in description

* Fri Apr 23 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.6-2mdv2010.1
+ Revision: 538373
- add upstream patch to fix a unicode bug when moving torrents

* Tue Apr 20 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.6-1mdv2010.1
+ Revision: 537236
- new version 2.2.6

* Wed Apr 07 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.5-1mdv2010.1
+ Revision: 532716
- new upstream release 2.2.5
- drop patch1, merged upstream
- bump release

* Tue Apr 06 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.4-2mdv2010.1
+ Revision: 532251
- add upstream patch to fix crash when adding labels

* Tue Apr 06 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.4-1mdv2010.1
+ Revision: 532047
- new upstream release 2.2.4

* Mon Apr 05 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.3-1mdv2010.1
+ Revision: 531513
- new upstream release 2.2.3
- drop patch1, merged upstream

* Tue Mar 23 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.2-2mdv2010.1
+ Revision: 526969
- add upstream patch to fix crash when deleting a torrent just after pausing it

* Mon Mar 22 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.2-1mdv2010.1
+ Revision: 526684
- new upstream release 2.2.2
- drop patch1, merged upstream

* Sun Mar 21 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.1-2mdv2010.1
+ Revision: 526018
- add upstream patch for more robust fast-resume

* Sat Mar 20 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.1-1mdv2010.1
+ Revision: 525481
- new upstream release 2.2.1

* Mon Mar 15 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.0-1mdv2010.1
+ Revision: 519114
- 2.2.0 final

* Tue Mar 09 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.0-0.rc2.1mdv2010.1
+ Revision: 516805
- new upstream release 2.2.0 rc2

* Sun Mar 07 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.0-0.rc1.1mdv2010.1
+ Revision: 515319
- new upstream release 2.2.0 rc1

* Thu Feb 11 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.0-0.beta4.1mdv2010.1
+ Revision: 504168
- 2.2.0 beta4

* Tue Feb 09 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.0-0.beta3.1mdv2010.1
+ Revision: 503161
- update to 2.2.0beta3

* Mon Feb 08 2010 Anssi Hannula <anssi@mandriva.org> 2.2.0-0.beta2.2mdv2010.1
+ Revision: 501882
- rebuild for new boost

  + Ahmad Samir <ahmadsamir@mandriva.org>
    - clean spec

* Thu Feb 04 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.0-0.beta2.1mdv2010.1
+ Revision: 500657
- Update to 2.2.0beta2
- Drop patch0

* Thu Feb 04 2010 Funda Wang <fwang@mandriva.org> 2.2.0-0.beta1.3mdv2010.1
+ Revision: 500582
- rebuild

* Wed Feb 03 2010 Funda Wang <fwang@mandriva.org> 2.2.0-0.beta1.2mdv2010.1
+ Revision: 500307
- rebuild for new boost

* Sat Jan 30 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.2.0-0.beta1.1mdv2010.1
+ Revision: 498420
- Update to 2.2.0beta1
- Add upstream patch to fix alternative upload speed limit overwriting standard
   upload speed limit
- Add patch to disable extra debug (from Fedora)

* Sun Jan 24 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.1.2-1mdv2010.1
+ Revision: 495605
- new upstream release 2.1.2
- drop patch merged upstream

* Thu Jan 21 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.1.1-3mdv2010.1
+ Revision: 494764
- add upstream patch to fix folder renaming

* Thu Jan 21 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.1.1-2mdv2010.1
+ Revision: 494423
- use better build method to get proper debug info (from Fedora)
- clean spec

* Wed Jan 20 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.1.1-1mdv2010.1
+ Revision: 494265
- bug fix release 2.1.1

* Mon Jan 18 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.1.0-2mdv2010.1
+ Revision: 493293
- it can work with libtorrent-rasterbar-devel >= 0.14.4 too

* Mon Jan 18 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.1.0-1mdv2010.1
+ Revision: 493245
- 2.1.0 final release

* Sun Jan 17 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.1.0-0.rc7.2mdv2010.1
+ Revision: 492535
- build qbittorrent-nox, a headless client

* Fri Jan 15 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.1.0-0.rc7.1mdv2010.1
+ Revision: 491590
- new release 2.1.0rc7

* Wed Jan 13 2010 Ahmad Samir <ahmadsamir@mandriva.org> 2.1.0-0.rc6.1mdv2010.1
+ Revision: 490476
- update to 2.1.0-rc6

* Mon Jan 11 2010 Jérôme Brenier <incubusss@mandriva.org> 2.1.0-0.rc5.1mdv2010.1
+ Revision: 489792
- new version 2.1.0rc5

* Sat Jan 09 2010 Jérôme Brenier <incubusss@mandriva.org> 2.1.0-0.rc4.1mdv2010.1
+ Revision: 488211
- new upstream release 2.1.0rc4
- update minimal version of libtorrent-rasterbar-devel BR

* Sun Jan 03 2010 Jérôme Brenier <incubusss@mandriva.org> 2.0.5-1mdv2010.1
+ Revision: 485776
- import qbittorrent


